@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/manifest.tcl,v $
-# $Date: 1998/10/28 17:27:15 $
-# $Revision: 1.18.1.247 $
+# $Source: /home/nlfm/Zircon/installer/RCS/manifest.tcl,v $
+# $Date: 1998/11/06 10:07:54 $
+# $Revision: 1.18.1.251 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -12,6 +12,8 @@
 array set Manifest [list  \
     README					{} \
     [file join doc README.ONS]			{} \
+    [file join doc README.SOCKS]		{} \
+    [file join doc README.Y2K]			{} \
     [file join doc README.load]			{} \
     [file join doc README.look]			{} \
     [file join doc README.prefs]		{} \
@@ -109,6 +111,7 @@ array set Manifest [list  \
     [file join lib Notice.tcl]			{copy} \
     [file join lib On.tcl]			{copy} \
     [file join lib Protect.tcl]			{copy} \
+    [file join lib SOCKS.tcl]			{copy} \
     [file join lib Server.tcl]			{copy} \
     [file join lib Service.tcl]			{copy} \
     [file join lib Sound.tcl]			{copy} \
@@ -248,5 +251,5 @@ array set Manifest [list  \
 set Index "lib [file join plugins Dcc] [file join plugins Sed]"
 #
 set Version 1.18
-set Patchlevel 191
+set Patchlevel 195
 
