@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Classes.tcl,v $
-# $Date: 1998/10/28 17:27:02 $
-# $Revision: 1.18.1.92 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Classes.tcl,v $
+# $Date: 1998/11/06 10:07:31 $
+# $Revision: 1.18.1.93 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -352,6 +352,9 @@ class Net "
     closing	{}
     showlist	0
     listid	{}
+    sockshost	{}
+    socksport	{}
+    sockcmd	socket
 }
 #
 class Control {} {
