@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Net.tcl,v $
-# $Date: 1998/10/28 10:20:16 $
-# $Revision: 1.18.1.156 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
+# $Date: 1998/11/06 10:07:34 $
+# $Revision: 1.18.1.159 $
 #
 package provide zircon 1.18
 #
@@ -295,22 +295,24 @@ proc net_startIRC {this srv args} {
 	while {1} {
 	    set port [$srv selport]
 	    $ctl showServer $srv $port
-	    $this inform "Connecting to port $port of server $server"
-	    update idletasks
-	    $this slow
-	    set ndata(sock) {}
-	    if {[info exists zircon(sockshost)]} {
-		set scmd SOCKSet
-	    } {
-		set scmd socket
-		foreach x {myaddr myport } {
+	    switch [set scmd [$this sockcmd]] socket {
+		foreach x {myaddr myport} {
 		    switch {} $ndata($x) {} default {
 			append scmd " -$x $ndata($x)"
 		    }
 		}
-		append scmd " -async $server $port"
+	    } default {
+		switch {} [set ip [$srv ip]] {
+		    $this errmsg "No IP address for host $server. Cannot use SOCKS."
+		    return 0
+		}
+		set server $ip
 	    }
-	    if {[catch {eval $scmd} sock]} {
+	    $this inform "Connecting to port $port of server $server"
+	    update idletasks
+	    $this slow
+	    set ndata(sock) {}
+	    if {[catch {eval "$scmd -async $server $port"} sock]} {
 		$this errmsg "Cannot connect to port $port of server $server ($sock)"
 		set ndata(sock) {}
 		$this fast
@@ -351,6 +353,7 @@ proc net_startIRC {this srv args} {
 	    }
 	}
     }
+# This point is never reached
 }
 #
 proc net_abort {this sock} {
