@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/config.tcl,v $
-# $Date: 1998/07/01 09:34:48 $
-# $Revision: 1.18.1.33 $
+# $Date: 1998/10/30 10:32:47 $
+# $Revision: 1.18.1.34 $
 #
 package provide zircon 1.18
 #
@@ -196,12 +196,12 @@ proc confAddIRCName {net win y} {
     confAddIt $net $win $y IRCname {IRC name} ircnames
 }
 #
-proc doCAS {net sid pos win dflt hst prt pwd onk opw} {
+proc doCAS {net sid pos win dflt hst prt ip pwd onk opw} {
     switch {} $hst return
     global lbdata
     switch {} $sid {
 	global newSv
-	set id [Server [newName _srvr] -host $hst -oper $onk -operpw \
+	set id [Server [newName _srvr] -host $hst -ip $ip -oper $onk -operpw \
 	  $opw -passwd $pwd]
 	switch {} $prt {set prt 6667}
 	$id configure -port $prt
@@ -219,6 +219,7 @@ proc doCAS {net sid pos win dflt hst prt pwd onk opw} {
 	}
 	switch {} $prt {set prt 6667}
 	set new(port) $prt
+	set new(ip) $ip
 	set new(oper) $onk
 	set new(operpw) $opw
 	set new(passwd) $pwd
@@ -285,7 +286,7 @@ proc confAddServer {net win y} {
     confDABtns $net
     switch *NEW* $val {
 	mkEntryBox .@cas$net "[$net name] - New Server" {Enter the new server details:} \
-	  [list [list hostname {}] [list port 6667] \
+	  [list [list hostname {}] [list port 6667] [list {IP Address} {}] \
 	  [list {Server passwd} {}] [list {Op Nick} {}] \
 	  [list {Op passwd} {}]] [list ok "doCAS $net {} $pos $win 0"] \
 	  [list default "doCAS $net {} $pos $win 1"] \
@@ -295,7 +296,7 @@ proc confAddServer {net win y} {
 	upvar #0 new$sid new
 	confSelClear $win $pos
 	mkEntryBox .@cas$net "[$net name] - Edit Server" {Edit the server details:} \
-	  [list [list hostname $val] [list port $new(port)] \
+	  [list [list hostname $val] [list port $new(port)] [list {IP Address} $new(ip)] \
 	  [list {Server passwd} $new(passwd)] \
 	  [list {Op Nick} $new(oper)] [list {Op passwd} $new(operpw)]] \
 	  [list ok "doCAS $net $sid $pos $win 0"] \
